@@ -33,7 +33,6 @@ return JS.CIPChirality.ruleNames[rule];
 }, "~N");
 Clazz.makeConstructor (c$, 
 function () {
-System.out.println ("TESTING Rule 1b option " + this.rule1bOption);
 });
 Clazz.defineMethod (c$, "init", 
  function () {
@@ -348,12 +347,13 @@ case 7:
 cipAtom.sortSubstituents (-2147483648);
 break;
 case 9:
-if (!cipAtom.setupRule6 (false)) continue;
+rs = cipAtom.setupRule6 (false);
+if (rs == 0) continue;
 break;
 }
 var nPrioritiesPrev = cipAtom.nPriorities;
-if (cipAtom.sortSubstituents (0)) {
-if (JU.Logger.debugging) {
+if (rs == 0 && cipAtom.sortSubstituents (0)) {
+if (JU.Logger.debugging && cipAtom.h1Count < 2) {
 JU.Logger.info (this.currentRule + ">>>>" + cipAtom);
 for (var i = 0; i < cipAtom.bondCount; i++) {
 if (cipAtom.atoms[i] != null) JU.Logger.info (cipAtom.atoms[i] + " " + cipAtom.priorities[i]);
@@ -439,7 +439,9 @@ this.atoms = null;
 this.nAtoms = 0;
 this.bsPath = null;
 this.myPath = "";
-this.priorities = null;
+this.oldPriorities = null;
+this.priorities =  Clazz.newIntArray (4, 0);
+this.oldNPriorities = 0;
 this.nPriorities = 0;
 this.nRootDuplicates = 0;
 this.htPathPoints = null;
@@ -467,7 +469,6 @@ Clazz.instantialize (this, arguments);
 }, JS.CIPChirality, "CIPAtom", null, [Comparable, Cloneable]);
 Clazz.prepareFields (c$, function () {
 this.atoms =  new Array (4);
-this.priorities =  Clazz.newIntArray (4, 0);
 this.bsTemp =  new JU.BS ();
 });
 Clazz.makeConstructor (c$, 
@@ -475,10 +476,33 @@ function () {
 });
 Clazz.defineMethod (c$, "setupRule6", 
 function (a) {
-if (this.nPriorities > 2 || (a ? this.countDuplicates (this.atomIndex) : this.nRootDuplicates) <= 2) return false;
+if (this.nPriorities > 2 || (a ? this.countDuplicates (this.atomIndex) : this.nRootDuplicates) <= 2) return 0;
+var b = (this.priorities[3] != 1 && !a);
 this.b$["JS.CIPChirality"].root.rule6refIndex = this.atoms[this.priorities[2]].atomIndex;
+if (b) this.saveRestorePriorities (false);
 this.sortSubstituents (-2147483648);
-return true;
+var c = 0;
+if (!this.sortSubstituents (0)) return 0;
+c = this.checkHandedness ();
+if (c == 0 || !b) {
+return c;
+}this.b$["JS.CIPChirality"].root.rule6refIndex = this.atoms[1].atomIndex;
+this.saveRestorePriorities (true);
+this.sortSubstituents (-2147483648);
+this.sortSubstituents (0);
+var d = this.checkHandedness ();
+return d == c ? c : 0;
+}, "~B");
+Clazz.defineMethod (c$, "saveRestorePriorities", 
+ function (a) {
+if (a) {
+this.priorities = this.oldPriorities;
+this.nPriorities = this.oldNPriorities;
+} else {
+this.oldPriorities = java.util.Arrays.copyOf (this.priorities, 4);
+this.oldNPriorities = this.nPriorities;
+}for (var b = 0; b < this.nAtoms; b++) this.atoms[b].saveRestorePriorities (a);
+
 }, "~B");
 Clazz.defineMethod (c$, "countDuplicates", 
  function (a) {
@@ -624,9 +648,9 @@ function (a, b, c, d, e) {
 if (a >= this.atoms.length) {
 if (JU.Logger.debugging) JU.Logger.info (" too many bonds on " + this.atom);
 return null;
-}if (this.parent == null) {
-if (b.getIsotopeNumber () == 1) {
+}if (b.getElementNumber () == 1 && b.getIsotopeNumber () == 0) {
 if (++this.h1Count > 1) {
+if (this.parent == null) {
 if (JU.Logger.debuggingHigh) JU.Logger.info (" second H atom found on " + this.atom);
 return null;
 }}}return this.atoms[a] = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (b, this, d, c, e);
@@ -651,7 +675,7 @@ if (!this.isSP3) return false;
 }b = new Boolean (b | (this.b$["JS.CIPChirality"].currentRule == 6 || this.b$["JS.CIPChirality"].currentRule == 8)).valueOf ();
 var c =  Clazz.newIntArray (4, 0);
 var d =  Clazz.newIntArray (4, 0);
-if (JU.Logger.debuggingHigh) {
+if (JU.Logger.debuggingHigh && this.h1Count < 2) {
 JU.Logger.info (this.b$["JS.CIPChirality"].root + "---sortSubstituents---" + this);
 for (var e = 0; e < 4; e++) {
 JU.Logger.info (this.b$["JS.CIPChirality"].getRuleName (this.b$["JS.CIPChirality"].currentRule) + ": " + this + "[" + e + "]=" + this.atoms[e].myPath + " " + Integer.toHexString (this.priorities[e]));
@@ -686,9 +710,9 @@ this.newAtoms =  new Array (4);
 for (var i = 0; i < 4; i++) {
 var j = c[i];
 var k = this.newAtoms[j] = this.atoms[i];
+if (k.atom != null) this.bsTemp.set (d[i]);
 if (this.b$["JS.CIPChirality"].currentRule == 99) continue;
 this.priorities[j] = d[i];
-if (k.atom != null) this.bsTemp.set (d[i]);
 }
 if (this.b$["JS.CIPChirality"].currentRule == 99) {
 return false;
@@ -767,8 +791,7 @@ Clazz.defineMethod (c$, "sortByRule",
 var b = this.b$["JS.CIPChirality"].currentRule;
 this.b$["JS.CIPChirality"].currentRule = a;
 var c = this.b$["JS.CIPChirality"].root.rule6refIndex;
-if (a == 9) this.setupRule6 (true);
-var d = this.sortSubstituents (0);
+var d = (a == 9 ? this.setupRule6 (true) != 0 : this.sortSubstituents (0));
 this.b$["JS.CIPChirality"].root.rule6refIndex = c;
 this.b$["JS.CIPChirality"].currentRule = b;
 return d;
@@ -878,7 +901,9 @@ return ((this.atomIndex == this.b$["JS.CIPChirality"].root.rule6refIndex) == (a.
 Clazz.defineMethod (c$, "getAuxEneWinnerChirality", 
  function (a, b, c, d) {
 var e = this.getAuxEneEndWinner (a, a.nextSP2, null);
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + " alkene end winner1 " + e);
 var f = (e == null || e.atom == null ? null : this.getAuxEneEndWinner (b, b.nextSP2, d));
+if (JU.Logger.debuggingHigh) JU.Logger.info (this + " alkene end winners " + e + f);
 return this.b$["JS.CIPChirality"].getEneChirality (e, a, b, f, c, false);
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~B,~A");
 Clazz.defineMethod (c$, "getAuxEneEndWinner", 
@@ -947,7 +972,7 @@ var f = 0;
 var g =  new Array (1);
 var h = false;
 var i = true;
-var j = (!this.isAlkene && this.nPriorities == (a == null ? 2 : 1));
+var j = (!this.isAlkene && this.nPriorities <= (a == null ? 2 : 1));
 for (var k = 0; k < 4; k++) {
 var l = this.atoms[k];
 if (l != null && !l.isDuplicate && !l.isTerminal) {
@@ -987,6 +1012,7 @@ this.auxEZ = this.alkeneChild.auxEZ = 7;
 } else {
 if (m != null && m[0] != 8) {
 this.auxEZ = this.alkeneChild.auxEZ = e;
+if (JU.Logger.debuggingHigh) JU.Logger.info ("alkene type " + this + " " + (this.auxEZ == 6 ? "E" : "Z"));
 } else if (!l) {
 switch (e) {
 case 17:
